# pentaho-rest-api 

[![Build Status](https://travis-ci.org/AlayaCare/pentaho-rest-api.svg?branch=master)](https://travis-ci.org/AlayaCare/pentaho-rest-api)

Python Library to access the Pentaho BA REST API

### Version
1.0.11

### Installation

Installing the library from the pip package

```sh
$ pip install pentaho-rest-api
```

### Development

The development structure for this app is to make a separate
modules for each distinct base api from [http://javadoc.pentaho.com/bi-platform500/webservice500/]

### Todos
 - User role management
 - File/Directory Management

License
----
GPL